
const STORAGE_THEME = 'theme'

const prefersDark = window.matchMedia('(prefers-color-scheme: dark)').matches
const localTheme = 'light'
// localStorage.getItem(STORAGE_THEME) || (prefersDark ? 'dark' : 'light')

const theme = ref<'light' | 'dark'>(localTheme as 'light' | 'dark')

const chartGraphicTextColor = computed(() =>
  theme.value === 'dark' ? '#ccc' : '#4d4d4d'
)

watchEffect(() => {
  const html = document.querySelector('html')
  if (theme.value === 'dark') {
    html?.classList.remove('light')
    html?.classList.add('dark')
  } else {
    html?.classList.remove('dark')
    html?.classList.add('light')
  }
  document.documentElement.setAttribute('data-theme', theme.value)
  localStorage.setItem(STORAGE_THEME, theme.value)
})

function toggle() {
  theme.value = theme.value === 'light' ? 'dark' : 'light'
}
function setTheme(value: 'light' | 'dark') {
  theme.value = value
}

export function useTheme() {
  return {
    theme,
    toggle,
    setTheme,
    chartGraphicTextColor,
  }
}
