var __awaiter =
  (this && this.__awaiter) ||
  function (thisArg, _arguments, P, generator) {
    function adopt(value) {
      return value instanceof P
        ? value
        : new P(function (resolve) {
            resolve(value)
          })
    }
    return new (P || (P = Promise))(function (resolve, reject) {
      function fulfilled(value) {
        try {
          step(generator.next(value))
        } catch (e) {
          reject(e)
        }
      }
      function rejected(value) {
        try {
          step(generator['throw'](value))
        } catch (e) {
          reject(e)
        }
      }
      function step(result) {
        result.done
          ? resolve(result.value)
          : adopt(result.value).then(fulfilled, rejected)
      }
      step((generator = generator.apply(thisArg, _arguments || [])).next())
    })
  }
import * as zmq from 'jszmq'
import { Buffer } from 'buffer'
export default class ZmqClient {
  constructor(type) {
    switch (type) {
      case 'req':
        this.sock = zmq.socket('req')
        break
      case 'sub':
        this.sock = zmq.socket('sub')
        break
      case 'pub':
        this.sock = zmq.socket('pub')
        break
      default:
        throw new Error('unsupported client type')
    }
  }
  zmqReq(host, request_type, dataStr, timeout) {
    return __awaiter(this, void 0, void 0, function* () {
      this.sock.connect(host)
      var request = new Array()
      request[0] = request_type
      request[1] = dataStr
      this.sock.send(request)
      return Promise.race([
        new Promise((resolve, reject) => {
          this.sock.on('message', function (message) {
            resolve(message.toString())
          })
        }),
        new Promise((resolve, reject) => {
          setTimeout(() => {
            reject('timeout error')
          }, timeout)
        }),
      ])
      // var isMessageArrived = false;
      // const result: string = "";
      // var msgReceiveTimer = setTimeout(() => {
      //     if (!isMessageArrived) {
      //         console.log("msg receive timed out");
      //     }
      // }, timeout); // 设置超时时间为5秒
    })
  }
  zmqSub(host, callback) {
    this.sock.connect(host)
    this.sock.on('message', callback)
  }
  zmqPub(host) {
    this.sock.connect(host)
  }
  subscribe(topic) {
    this.sock.subscribe(topic)
  }
  unsubscribe(topic) {
    this.sock.unsubscribe(topic)
  }
  publishHex(topic, dataStr) {
    return __awaiter(this, void 0, void 0, function* () {
      var request = new Array()
      request[0] = topic
      const buf = Buffer.from(dataStr, 'hex')
      request[1] = buf
      this.sock.send(request)
    })
  }
  publishStr(topic, dataStr) {
    return __awaiter(this, void 0, void 0, function* () {
      var request = new Array()
      request[0] = topic
      request[1] = dataStr
      this.sock.send(request)
    })
  }
  close(host, callback) {
    if (callback) {
      this.sock.removeListener('message', callback)
    }
    this.sock.disconnect(host)
    this.sock.close()
  }
}
//# sourceMappingURL=zmqClient.js.map
